@@ -29,6 +29,7 @@ class Batch:
         - status: Status of the batch
         - webhook: Webhook where the job results are automatically sent to.
         - sequence_builder: Pulser sequence of the batch
+        - device_status: Status of the device where the batch is running.
         - jobs: Dictionnary of all the jobs added to the batch.
         - jobs_count: number of jobs added to the batch
         - jobs_count_per_status: number of jobs per status
@@ -46,6 +47,7 @@ class Batch:
     webhook: str
     _client: Client
     sequence_builder: str
+    device_status: str = None
     jobs: Dict[int, Job] = field(default_factory=dict)
     jobs_count: int = 0
     jobs_count_per_status: Dict[str, int] = field(default_factory=dict)
